Summary: Exif and Iptc metadata manipulation library
Name:	 exiv2
Version: 0.26
Release: 1
License: GPLv2+
Group:   Applications/Multimedia
URL: 	 http://www.exiv2.org/
Source0: http://www.exiv2.org/builds/%{name}-%{version}-trunk.tar.gz
Patch0:  %{name}-%{version}-aix.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: make
# docs
BuildRequires: doxygen graphviz libxslt

BuildRequires: expat-devel >= 2.2.4-1
BuildRequires: gcc >= 4.5.4-1
BuildRequires: gcc-c++ >= 4.5.4-1
BuildRequires: gettext >= 0.10.40-6
BuildRequires: libiconv >= 1.15-1
BuildRequires: libstdc++-devel >= 4.5.4-1
BuildRequires: zlib-devel >= 1.2.3-7

Requires: gettext >= 0.10.40-6
Requires: libgcc >= 4.5.4-1
Requires: libstdc++ >= 4.5.4-1

Requires: %{name}-libs = %{version}-%{release}

%define _libdir64 %{_prefix}/lib64

%description
A command line utility to access image metadata, allowing one to:
* print the Exif metadata of Jpeg images as summary info, interpreted values,
  or the plain data for each tag
* print the Iptc metadata of Jpeg images
* print the Jpeg comment of Jpeg images
* set, add and delete Exif and Iptc metadata of Jpeg images
* adjust the Exif timestamp (that's how it all started...)
* rename Exif image files according to the Exif timestamp
* extract, insert and delete Exif metadata (including thumbnails),
  Iptc metadata and Jpeg comments


%package devel
Summary: Header files, libraries and development documentation for %{name}
Group:   Applications/Multimedia
Requires: %{name}-libs = %{version}-%{release}

%description devel
%{summary}.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "gcc -maix64".


%package libs
Summary: Exif and Iptc metadata manipulation library
Group:   Applications/Multimedia
Requires: expat >= 2.2.4-1
Requires: gettext >= 0.10.40-6
Requires: libgcc >= 4.5.4-1
Requires: libiconv >= 1.15-1
Requires: libstdc++ >= 4.5.4-1
Requires: zlib >= 1.2.3-7

%description libs
A C++ library to access image metadata, supporting full read and write access
to the Exif and Iptc metadata, Exif MakerNote support, extract and delete 
methods for Exif thumbnails, classes to access Ifd and so on.

The library is available as 32-bit and 64-bit.


%package doc
Summary: API documentation for %{name}
Group:   Applications/Multimedia

%description doc
%{summary}.


%prep
%setup -q -n %{name}-trunk
%patch0
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
export CFLAGS="-DSYSV -D_AIX -D_AIX32 -D_AIX41 -D_AIX43 -D_AIX51 -D_ALL_SOURCE -DFUNCPROTO=15 -O6 -I/opt/freeware/include"
export CXXFLAGS="-DSYSV -D_AIX -D_AIX32 -D_AIX41 -D_AIX43 -D_AIX51 -D_ALL_SOURCE -DFUNCPROTO=15 -O6 -I/opt/freeware/include"

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
export CC="gcc -maix64 -pthread"
export CXX="g++ -maix64 -pthread"
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --mandir=%{_mandir} \
    --disable-visibility
gmake %{?_smp_mflags}

cd ../32bit
# now build the 32-bit version
export OBJECT_MODE=32
export CC="gcc -maix32 -pthread"
export CXX="g++ -maix32 -pthread"
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --disable-visibility
gmake %{?_smp_mflags}
gmake doc


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
gmake DESTDIR=${RPM_BUILD_ROOT} install

(
  cd ${RPM_BUILD_ROOT}%{_bindir}
  for f in * ; do
    mv -f ${f} ${f}_64
  done
)

cd ../32bit
export OBJECT_MODE=32
gmake DESTDIR=${RPM_BUILD_ROOT} install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
/usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}.a ${RPM_BUILD_ROOT}%{_libdir64}/lib%{name}.so*

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%doc 32bit/COPYING 32bit/doc/ChangeLog 32bit/README
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/*/*/*
/usr/bin/*


%files libs
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
/usr/lib/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files devel
%{_includedir}/*
%{_libdir}/*.la
%{_libdir64}/*.la
%{_libdir}/pkgconfig/*.pc
%{_libdir64}/pkgconfig/*.pc
/usr/include/*
/usr/lib/*.la
/usr/lib64/*.la


%files doc
%doc 32bit/doc/html


%changelog
* Thu Oct 12 2017 Michael Perzl <michael@perzl.org> - 0.26-1
- first version for AIX V5.1 and higher
